@@ -356,6 +356,7 @@ struct params {
     struct param follow_view_key;
     struct param behind_view_key;
     struct param above_view_key;
+    struct param eyes_view_key;
     struct param view_mode; /* coresponds to view_mode_t */
     struct param screenshot_key;
     struct param pause_key;
@@ -562,14 +563,17 @@ void init_game_configuration()
 	"# Key binding for paddling (on the ground) and flapping (in the air)" 
 	);
     INIT_PARAM_STRING( 
-	follow_view_key, "1" ,
+	follow_view_key, "z" ,
 	"# Key binding for the \"Follow\" camera mode" );
     INIT_PARAM_STRING( 
-	behind_view_key, "2" ,
+	behind_view_key, "x" ,
 	"# Key binding for the \"Behind\" camera mode" );
     INIT_PARAM_STRING( 
-	above_view_key, "3" ,
+	above_view_key, "c" ,
 	"# Key binding for the \"Above\" camera mode" );
+    INIT_PARAM_STRING( 
+	eyes_view_key, "v" ,
+	"# Key binding for the \"Tuxeye\" camera mode" );
     INIT_PARAM_INT( 
 	view_mode, 1,
 	"# Default view mode. Possible values are\n" 
@@ -725,7 +729,7 @@ void init_game_configuration()
 	track_marks, False ,
 	"# If true, then the players will leave track marks in the snow." );
     INIT_PARAM_BOOL( 
-	ui_snow, False ,
+	ui_snow, True ,
 	"# If true, then the ui screens will have falling snow." );
 
     INIT_PARAM_BOOL( 
@@ -772,6 +776,7 @@ FN_PARAM_STRING( paddle_key )
 FN_PARAM_STRING( above_view_key )
 FN_PARAM_STRING( behind_view_key )
 FN_PARAM_STRING( follow_view_key )
+FN_PARAM_STRING( eyes_view_key )
 FN_PARAM_INT( view_mode )
 FN_PARAM_STRING( screenshot_key )
 FN_PARAM_STRING( pause_key )
