@@ -304,7 +304,7 @@ static void draw_instructions(player_data_t *plyr)
             training_pause_for_tutorial_explanation();
             print_instruction(Localize("Well, while you are in the air, there", ""),1);
             print_instruction(Localize("are two things that you can do : doing", ""),2);
-            print_instruction(Localize("some funny tricks (DISABLED at the moment) shaking the phone,", ""),3);
+            print_instruction(Localize("some funny tricks shaking the phone,", ""),3);
             print_instruction(Localize("and flapping the wings (accelerate button)", ""),4);
             print_instruction(Localize("to fly longer and get faster.", ""),5);
             if(training_is_resumed()) step++;
