@@ -58,7 +58,7 @@
 #define JUMP_MAX_START_HEIGHT 0.30
 
 /* factor limit to be considered as a left or a right turn. useful only for tricks */
-#define TURN_FACTOR_LIMIT 0.1
+#define TURN_FACTOR_LIMIT 0.3
 
 static bool_t right_turn;
 static bool_t left_turn;
@@ -228,7 +228,7 @@ void racing_loop( scalar_t time_step )
                 plyr->control.back_flip = True;
             }
 #ifdef __APPLE__
-            TRDebugLog("tricks : %d",plyr->tricks);
+            TRDebugLog("tricks : %d\n",plyr->tricks);
 #endif
         }
         
@@ -297,6 +297,11 @@ void racing_loop( scalar_t time_step )
     accel_read(&ax,&ay,&az);
     scalar_t iPhone_turn_fact=0; //MV accelerometerTurnFact();
     iPhone_turn_fact=-ax/500.0;
+
+    if (abs(ax*ax + ay*ay + az*az - 1000000) > 1000000){
+        trick_modifier = True;}
+    else
+        trick_modifier = False;
     
     /*left_turn and right_turn are informations useful for tricks*/
     if (iPhone_turn_fact>TURN_FACTOR_LIMIT) {
@@ -310,7 +315,7 @@ void racing_loop( scalar_t time_step )
     
     plyr->control.turn_fact = iPhone_turn_fact;
     plyr->control.turn_animation = iPhone_turn_fact;
-    
+
     
     /*
      * Paddling
@@ -566,6 +571,14 @@ START_KEYBOARD_CB( behind_view_cb )
 }
 END_KEYBOARD_CB
 
+START_KEYBOARD_CB( eyes_view_cb )
+{
+    if ( release ) return;
+    set_view_mode( plyr, TUXEYE );
+    setparam_view_mode( TUXEYE );
+}
+END_KEYBOARD_CB
+
 START_KEYBOARD_CB( screenshot_cb )
 {
     if ( release ) return;
@@ -620,6 +633,8 @@ void racing_register()
                                follow_view_cb );
     status |= add_keymap_entry( RACING, CONFIGURABLE_KEY, 
                                "c", getparam_above_view_key, above_view_cb );
+    status |= add_keymap_entry( RACING, CONFIGURABLE_KEY, 
+                               "v", getparam_eyes_view_key, eyes_view_cb );
     
     status |= add_keymap_entry( RACING, CONFIGURABLE_KEY, 
                                "=", getparam_screenshot_key, screenshot_cb );
@@ -637,7 +652,7 @@ void racing_register()
 
 void racing_mouse_func( int button, int state, int x, int y ) {
     static int noquit = 1;
-    printf("racing_mouse_func %d %d %d\n", x, y, noquit);
+
     /* Check screen controls */
     paddling = False;
     braking = False;
